// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "kalzium_libscience_debug.h"


Q_LOGGING_CATEGORY(KALZIUM_LIBSCIENCE_LOG, "org.kde.kalzium.libscience", QtInfoMsg)

