/********************************************************************************
** Form generated from reading UI file 'moleculeviewerwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MOLECULEVIEWERWIDGET_H
#define UI_MOLECULEVIEWERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "../../compoundviewer/kalziumglwidget.h"

QT_BEGIN_NAMESPACE

class Ui_moleculeViewerForm
{
public:
    QGridLayout *gridLayout;
    QWidget *widget_2;
    QVBoxLayout *verticalLayout_6;
    QGridLayout *gridLayout_3;
    QLabel *labelStyle;
    QHBoxLayout *horizontalLayout_5;
    QComboBox *styleCombo;
    KalziumGLWidget *glWidget;
    QWidget *widget;
    QVBoxLayout *verticalLayout_4;
    QVBoxLayout *verticalLayout_3;
    QTabWidget *tabWidget;
    QWidget *display;
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QSpacerItem *spacer;
    QWidget *edit;
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *editTabLayout;
    QSpacerItem *spacer_2;
    QPushButton *clearDrawingButton;
    QWidget *measure;
    QLabel *label_10;
    QGroupBox *groupBox;
    QGridLayout *gridLayout1;
    QGridLayout *gridLayout2;
    QLabel *label_3;
    QLabel *nameLabel;
    QLabel *label_7;
    QLabel *formulaLabel;
    QLabel *label_4;
    QLabel *weightLabel;

    void setupUi(QWidget *moleculeViewerForm)
    {
        if (moleculeViewerForm->objectName().isEmpty())
            moleculeViewerForm->setObjectName("moleculeViewerForm");
        moleculeViewerForm->resize(760, 523);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(moleculeViewerForm->sizePolicy().hasHeightForWidth());
        moleculeViewerForm->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(moleculeViewerForm);
        gridLayout->setObjectName("gridLayout");
        widget_2 = new QWidget(moleculeViewerForm);
        widget_2->setObjectName("widget_2");
        verticalLayout_6 = new QVBoxLayout(widget_2);
        verticalLayout_6->setObjectName("verticalLayout_6");
        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName("gridLayout_3");
        labelStyle = new QLabel(widget_2);
        labelStyle->setObjectName("labelStyle");
        labelStyle->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(labelStyle, 0, 0, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        styleCombo = new QComboBox(widget_2);
        styleCombo->setObjectName("styleCombo");
        styleCombo->setMinimumSize(QSize(160, 0));

        horizontalLayout_5->addWidget(styleCombo);


        gridLayout_3->addLayout(horizontalLayout_5, 0, 1, 1, 1);


        verticalLayout_6->addLayout(gridLayout_3);

        glWidget = new KalziumGLWidget(widget_2);
        glWidget->setObjectName("glWidget");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(10);
        sizePolicy1.setVerticalStretch(10);
        sizePolicy1.setHeightForWidth(glWidget->sizePolicy().hasHeightForWidth());
        glWidget->setSizePolicy(sizePolicy1);
        glWidget->setMinimumSize(QSize(240, 240));
        glWidget->setSizeIncrement(QSize(10, 10));

        verticalLayout_6->addWidget(glWidget);


        gridLayout->addWidget(widget_2, 0, 1, 1, 1);

        widget = new QWidget(moleculeViewerForm);
        widget->setObjectName("widget");
        widget->setMaximumSize(QSize(300, 16777215));
        verticalLayout_4 = new QVBoxLayout(widget);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        tabWidget = new QTabWidget(widget);
        tabWidget->setObjectName("tabWidget");
        display = new QWidget();
        display->setObjectName("display");
        verticalLayout = new QVBoxLayout(display);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(display);
        label->setObjectName("label");
        label->setEnabled(true);
        label->setMaximumSize(QSize(266, 16777215));
        label->setWordWrap(true);

        verticalLayout->addWidget(label);

        spacer = new QSpacerItem(148, 43, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacer);

        tabWidget->addTab(display, QString());
        edit = new QWidget();
        edit->setObjectName("edit");
        verticalLayout_2 = new QVBoxLayout(edit);
        verticalLayout_2->setObjectName("verticalLayout_2");
        editTabLayout = new QVBoxLayout();
        editTabLayout->setObjectName("editTabLayout");
        spacer_2 = new QSpacerItem(88, 43, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        editTabLayout->addItem(spacer_2);

        clearDrawingButton = new QPushButton(edit);
        clearDrawingButton->setObjectName("clearDrawingButton");

        editTabLayout->addWidget(clearDrawingButton);


        verticalLayout_2->addLayout(editTabLayout);

        tabWidget->addTab(edit, QString());
        measure = new QWidget();
        measure->setObjectName("measure");
        label_10 = new QLabel(measure);
        label_10->setObjectName("label_10");
        label_10->setGeometry(QRect(20, 20, 221, 141));
        label_10->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        label_10->setWordWrap(true);
        tabWidget->addTab(measure, QString());

        verticalLayout_3->addWidget(tabWidget);


        verticalLayout_4->addLayout(verticalLayout_3);

        groupBox = new QGroupBox(widget);
        groupBox->setObjectName("groupBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy2);
        groupBox->setMinimumSize(QSize(240, 110));
        gridLayout1 = new QGridLayout(groupBox);
        gridLayout1->setObjectName("gridLayout1");
        gridLayout2 = new QGridLayout();
        gridLayout2->setObjectName("gridLayout2");
        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout2->addWidget(label_3, 0, 0, 1, 1);

        nameLabel = new QLabel(groupBox);
        nameLabel->setObjectName("nameLabel");

        gridLayout2->addWidget(nameLabel, 0, 1, 1, 1);

        label_7 = new QLabel(groupBox);
        label_7->setObjectName("label_7");
        label_7->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout2->addWidget(label_7, 1, 0, 1, 1);

        formulaLabel = new QLabel(groupBox);
        formulaLabel->setObjectName("formulaLabel");

        gridLayout2->addWidget(formulaLabel, 1, 1, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout2->addWidget(label_4, 2, 0, 1, 1);

        weightLabel = new QLabel(groupBox);
        weightLabel->setObjectName("weightLabel");

        gridLayout2->addWidget(weightLabel, 2, 1, 1, 1);


        gridLayout1->addLayout(gridLayout2, 0, 0, 1, 1);


        verticalLayout_4->addWidget(groupBox);


        gridLayout->addWidget(widget, 0, 0, 1, 1);

#if QT_CONFIG(shortcut)
        labelStyle->setBuddy(styleCombo);
#endif // QT_CONFIG(shortcut)

        retranslateUi(moleculeViewerForm);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(moleculeViewerForm);
    } // setupUi

    void retranslateUi(QWidget *moleculeViewerForm)
    {
        labelStyle->setText(tr2i18n("Style:", nullptr));
        label->setText(tr2i18n("Load a molecule and use the mouse pointer and scroll wheel to change the view point.", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(display), tr2i18n("Display", nullptr));
        clearDrawingButton->setText(tr2i18n("Clear drawing", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(edit), tr2i18n("Edit", nullptr));
        label_10->setText(tr2i18n("Click on 2 atoms to measure a distance, on 3 atoms to measure an angle, on 4 atoms to measure a dihedral angle.", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(measure), tr2i18n("Measure", nullptr));
        groupBox->setTitle(tr2i18n("Statistics", nullptr));
        label_3->setText(tr2i18n("Name:", nullptr));
        nameLabel->setText(QString());
        label_7->setText(tr2i18n("Formula:", nullptr));
        formulaLabel->setText(QString());
        label_4->setText(tr2i18n("Weight:", nullptr));
        weightLabel->setText(QString());
        (void)moleculeViewerForm;
    } // retranslateUi

};

namespace Ui {
    class moleculeViewerForm: public Ui_moleculeViewerForm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MOLECULEVIEWERWIDGET_H

