/********************************************************************************
** Form generated from reading UI file 'equationview.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EQUATIONVIEW_H
#define UI_EQUATIONVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_EquationView
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer;
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QLineEdit *lineEdit;
    QPushButton *calculateButton;
    QFrame *frame;
    QVBoxLayout *verticalLayout_2;
    QLabel *answer_label;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *btnCopy;
    QLabel *lblHelp;

    void setupUi(QWidget *EquationView)
    {
        if (EquationView->objectName().isEmpty())
            EquationView->setObjectName("EquationView");
        EquationView->resize(581, 443);
        gridLayout = new QGridLayout(EquationView);
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout->setObjectName("gridLayout");
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 3, 0, 1, 1);

        verticalLayout = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        verticalLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        verticalLayout->setContentsMargins(0, 0, 0, 0);
#endif
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(EquationView);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        lineEdit = new QLineEdit(EquationView);
        lineEdit->setObjectName("lineEdit");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lineEdit->sizePolicy().hasHeightForWidth());
        lineEdit->setSizePolicy(sizePolicy);
        lineEdit->setMinimumSize(QSize(200, 0));
        lineEdit->setProperty("showClearButton", QVariant(true));

        verticalLayout->addWidget(lineEdit);

        calculateButton = new QPushButton(EquationView);
        calculateButton->setObjectName("calculateButton");

        verticalLayout->addWidget(calculateButton);

        frame = new QFrame(EquationView);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Raised);
        verticalLayout_2 = new QVBoxLayout(frame);
        verticalLayout_2->setObjectName("verticalLayout_2");
        answer_label = new QLabel(frame);
        answer_label->setObjectName("answer_label");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(answer_label->sizePolicy().hasHeightForWidth());
        answer_label->setSizePolicy(sizePolicy1);
        answer_label->setContextMenuPolicy(Qt::DefaultContextMenu);
        answer_label->setFrameShape(QFrame::NoFrame);
        answer_label->setFrameShadow(QFrame::Plain);
        answer_label->setTextFormat(Qt::RichText);
        answer_label->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        verticalLayout_2->addWidget(answer_label);


        verticalLayout->addWidget(frame);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        btnCopy = new QPushButton(EquationView);
        btnCopy->setObjectName("btnCopy");

        horizontalLayout->addWidget(btnCopy);


        verticalLayout->addLayout(horizontalLayout);

        lblHelp = new QLabel(EquationView);
        lblHelp->setObjectName("lblHelp");
        lblHelp->setText(QString::fromUtf8("TextLabel"));

        verticalLayout->addWidget(lblHelp);


        gridLayout->addLayout(verticalLayout, 2, 0, 1, 1);


        retranslateUi(EquationView);

        QMetaObject::connectSlotsByName(EquationView);
    } // setupUi

    void retranslateUi(QWidget *EquationView)
    {
        label->setText(tr2i18n("Equation:", nullptr));
#if QT_CONFIG(tooltip)
        lineEdit->setToolTip(tr2i18n("Enter the equation you want to balance in this field.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        lineEdit->setWhatsThis(tr2i18n("Enter the equation you want to balance in this field.", nullptr));
#endif // QT_CONFIG(whatsthis)
        lineEdit->setText(tr2i18n("aCH3(CH2)3COOH + bO2 -> cH2O + dCO2", nullptr));
#if QT_CONFIG(tooltip)
        calculateButton->setToolTip(tr2i18n("If you press this button the equation above will be balanced.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        calculateButton->setWhatsThis(tr2i18n("If you press this button the equation above will be balanced.", nullptr));
#endif // QT_CONFIG(whatsthis)
        calculateButton->setText(tr2i18n("&Calculate", nullptr));
        answer_label->setText(QString());
        btnCopy->setText(tr2i18n("Copy to Clipboard", nullptr));
        (void)EquationView;
    } // retranslateUi

};

namespace Ui {
    class EquationView: public Ui_EquationView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EQUATIONVIEW_H

