/****************************************************************************
** Meta object code from reading C++ file 'nuclearCalculator.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalzium-26.08.0/src/calculator/nuclearCalculator.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'nuclearCalculator.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17nuclearCalculatorE_t {};
} // unnamed namespace

template <> constexpr inline auto nuclearCalculator::qt_create_metaobjectdata<qt_meta_tag_ZN17nuclearCalculatorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "nuclearCalculator",
        "calculateInitAmount",
        "",
        "calculateFinalAmount",
        "calculateTime",
        "elementChanged",
        "index",
        "isotopeChanged",
        "halfLifeChanged",
        "calculate",
        "initAmtChanged",
        "finalAmtChanged",
        "timeChanged",
        "timeUnitCombobox",
        "QComboBox*",
        "comboBox",
        "massUnitCombobox",
        "getUnitIdFromCombobox",
        "KUnitConversion::UnitId",
        "sliderMoved",
        "x",
        "setMode",
        "mode",
        "init",
        "error"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'calculateInitAmount'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'calculateFinalAmount'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'calculateTime'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'elementChanged'
        QtMocHelpers::SlotData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'isotopeChanged'
        QtMocHelpers::SlotData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'halfLifeChanged'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'calculate'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'initAmtChanged'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'finalAmtChanged'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'timeChanged'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'timeUnitCombobox'
        QtMocHelpers::SlotData<void(QComboBox *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'massUnitCombobox'
        QtMocHelpers::SlotData<void(QComboBox *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'getUnitIdFromCombobox'
        QtMocHelpers::SlotData<KUnitConversion::UnitId(QComboBox *)>(17, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'sliderMoved'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'setMode'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'init'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'error'
        QtMocHelpers::SlotData<void(int)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<nuclearCalculator, qt_meta_tag_ZN17nuclearCalculatorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject nuclearCalculator::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17nuclearCalculatorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17nuclearCalculatorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17nuclearCalculatorE_t>.metaTypes,
    nullptr
} };

void nuclearCalculator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<nuclearCalculator *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->calculateInitAmount(); break;
        case 1: _t->calculateFinalAmount(); break;
        case 2: _t->calculateTime(); break;
        case 3: _t->elementChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->isotopeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->halfLifeChanged(); break;
        case 6: _t->calculate(); break;
        case 7: _t->initAmtChanged(); break;
        case 8: _t->finalAmtChanged(); break;
        case 9: _t->timeChanged(); break;
        case 10: _t->timeUnitCombobox((*reinterpret_cast<std::add_pointer_t<QComboBox*>>(_a[1]))); break;
        case 11: _t->massUnitCombobox((*reinterpret_cast<std::add_pointer_t<QComboBox*>>(_a[1]))); break;
        case 12: { KUnitConversion::UnitId _r = _t->getUnitIdFromCombobox((*reinterpret_cast<std::add_pointer_t<QComboBox*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KUnitConversion::UnitId*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->sliderMoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->setMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->init(); break;
        case 16: _t->error((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *nuclearCalculator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *nuclearCalculator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17nuclearCalculatorE_t>.strings))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int nuclearCalculator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
