/****************************************************************************
** Meta object code from reading C++ file 'kalzium.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalzium-26.08.0/src/kalzium.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kalzium.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7KalziumE_t {};
} // unnamed namespace

template <> constexpr inline auto Kalzium::qt_create_metaobjectdata<qt_meta_tag_ZN7KalziumE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kalzium",
        "numerationChanged",
        "",
        "openInformationDialog",
        "number",
        "elementHover",
        "num",
        "setupStatusBar",
        "slotSwitchtoTable",
        "index",
        "slotGlossary",
        "slotRS",
        "slotMoleculeviewer",
        "MoleculeDialog*",
        "slotOBConverter",
        "slotTables",
        "slotSwitchtoLookGradient",
        "slotSwitchtoLookScheme",
        "slotSwitchtoNumeration",
        "slotIsotopeTable",
        "slotPlotData",
        "showCalculator",
        "slotExportTable",
        "slotShowExportDialog",
        "showSettingsDialog",
        "slotUpdateSettings"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'numerationChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'openInformationDialog'
        QtMocHelpers::SlotData<void(int)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'elementHover'
        QtMocHelpers::SlotData<void(int)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'setupStatusBar'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSwitchtoTable'
        QtMocHelpers::SlotData<void(int)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'slotGlossary'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRS'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMoleculeviewer'
        QtMocHelpers::SlotData<MoleculeDialog *()>(12, 2, QMC::AccessPrivate, 0x80000000 | 13),
        // Slot 'slotOBConverter'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTables'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSwitchtoLookGradient'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotSwitchtoLookScheme'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotSwitchtoNumeration'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotIsotopeTable'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPlotData'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showCalculator'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotExportTable'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowExportDialog'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showSettingsDialog'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateSettings'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Kalzium, qt_meta_tag_ZN7KalziumE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kalzium::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KalziumE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KalziumE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KalziumE_t>.metaTypes,
    nullptr
} };

void Kalzium::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Kalzium *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->numerationChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->openInformationDialog((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->elementHover((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->setupStatusBar(); break;
        case 4: _t->slotSwitchtoTable((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->slotGlossary(); break;
        case 6: _t->slotRS(); break;
        case 7: { MoleculeDialog* _r = _t->slotMoleculeviewer();
            if (_a[0]) *reinterpret_cast<MoleculeDialog**>(_a[0]) = std::move(_r); }  break;
        case 8: _t->slotOBConverter(); break;
        case 9: _t->slotTables(); break;
        case 10: _t->slotSwitchtoLookGradient((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->slotSwitchtoLookScheme((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->slotSwitchtoNumeration((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->slotIsotopeTable(); break;
        case 14: _t->slotPlotData(); break;
        case 15: _t->showCalculator(); break;
        case 16: _t->slotExportTable(); break;
        case 17: _t->slotShowExportDialog(); break;
        case 18: _t->showSettingsDialog(); break;
        case 19: _t->slotUpdateSettings(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Kalzium::*)(int )>(_a, &Kalzium::numerationChanged, 0))
            return;
    }
}

const QMetaObject *Kalzium::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kalzium::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KalziumE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int Kalzium::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void Kalzium::numerationChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
