/********************************************************************************
** Form generated from reading UI file 'obconverterwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OBCONVERTERWIDGET_H
#define UI_OBCONVERTERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_OBConverterWidget
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout1;
    QPushButton *selectAllFileButton;
    QSpacerItem *spacerItem;
    QPushButton *deleteFileButton;
    QPushButton *addFileButton;
    QListWidget *FileListView;
    QHBoxLayout *hboxLayout;
    QLabel *label;
    KComboBox *InputTypeComboBox;
    QHBoxLayout *hboxLayout1;
    QLabel *label_2;
    KComboBox *OutputTypeComboBox;

    void setupUi(QWidget *OBConverterWidget)
    {
        if (OBConverterWidget->objectName().isEmpty())
            OBConverterWidget->setObjectName("OBConverterWidget");
        OBConverterWidget->resize(581, 443);
        gridLayout = new QGridLayout(OBConverterWidget);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        groupBox = new QGroupBox(OBConverterWidget);
        groupBox->setObjectName("groupBox");
        gridLayout1 = new QGridLayout(groupBox);
        gridLayout1->setSpacing(6);
        gridLayout1->setObjectName("gridLayout1");
        gridLayout1->setContentsMargins(9, 9, 9, 9);
        selectAllFileButton = new QPushButton(groupBox);
        selectAllFileButton->setObjectName("selectAllFileButton");

        gridLayout1->addWidget(selectAllFileButton, 3, 1, 1, 1);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout1->addItem(spacerItem, 2, 1, 1, 1);

        deleteFileButton = new QPushButton(groupBox);
        deleteFileButton->setObjectName("deleteFileButton");

        gridLayout1->addWidget(deleteFileButton, 1, 1, 1, 1);

        addFileButton = new QPushButton(groupBox);
        addFileButton->setObjectName("addFileButton");

        gridLayout1->addWidget(addFileButton, 0, 1, 1, 1);

        FileListView = new QListWidget(groupBox);
        FileListView->setObjectName("FileListView");
        FileListView->setSelectionMode(QAbstractItemView::MultiSelection);

        gridLayout1->addWidget(FileListView, 0, 0, 5, 1);


        gridLayout->addWidget(groupBox, 0, 0, 1, 2);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(OBConverterWidget);
        label->setObjectName("label");

        hboxLayout->addWidget(label);

        InputTypeComboBox = new KComboBox(OBConverterWidget);
        InputTypeComboBox->setObjectName("InputTypeComboBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(InputTypeComboBox->sizePolicy().hasHeightForWidth());
        InputTypeComboBox->setSizePolicy(sizePolicy);

        hboxLayout->addWidget(InputTypeComboBox);


        gridLayout->addLayout(hboxLayout, 1, 0, 1, 2);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setObjectName("hboxLayout1");
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        label_2 = new QLabel(OBConverterWidget);
        label_2->setObjectName("label_2");

        hboxLayout1->addWidget(label_2);

        OutputTypeComboBox = new KComboBox(OBConverterWidget);
        OutputTypeComboBox->setObjectName("OutputTypeComboBox");
        sizePolicy.setHeightForWidth(OutputTypeComboBox->sizePolicy().hasHeightForWidth());
        OutputTypeComboBox->setSizePolicy(sizePolicy);

        hboxLayout1->addWidget(OutputTypeComboBox);


        gridLayout->addLayout(hboxLayout1, 2, 0, 1, 2);

#if QT_CONFIG(shortcut)
        label->setBuddy(InputTypeComboBox);
        label_2->setBuddy(InputTypeComboBox);
#endif // QT_CONFIG(shortcut)

        retranslateUi(OBConverterWidget);

        QMetaObject::connectSlotsByName(OBConverterWidget);
    } // setupUi

    void retranslateUi(QWidget *OBConverterWidget)
    {
        groupBox->setTitle(tr2i18n("Files to convert", nullptr));
        selectAllFileButton->setText(tr2i18n("&Select all", nullptr));
        deleteFileButton->setText(tr2i18n("&Remove", nullptr));
        addFileButton->setText(tr2i18n("&Add", nullptr));
#if QT_CONFIG(whatsthis)
        FileListView->setWhatsThis(tr2i18n("<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:10pt; font-weight:400; font-style:normal; text-decoration:none;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">You see the files which will be converted here. Use the buttons to add and remove files from the list.</p></body></html>", nullptr));
#endif // QT_CONFIG(whatsthis)
        label->setText(tr2i18n("Convert from:", nullptr));
        label_2->setText(tr2i18n("Convert to:", nullptr));
        (void)OBConverterWidget;
    } // retranslateUi

};

namespace Ui {
    class OBConverterWidget: public Ui_OBConverterWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OBCONVERTERWIDGET_H

