/********************************************************************************
** Form generated from reading UI file 'settings_colors.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGS_COLORS_H
#define UI_SETTINGS_COLORS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_setupColors
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *dfgdfg;
    QWidget *tabBlocks;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel13;
    KColorButton *kcfg_block_s;
    QHBoxLayout *hboxLayout1;
    QLabel *textLabel14;
    KColorButton *kcfg_block_p;
    QHBoxLayout *hboxLayout2;
    QLabel *textLabel15;
    KColorButton *kcfg_block_d;
    QHBoxLayout *hboxLayout3;
    QLabel *textLabel16;
    KColorButton *kcfg_block_f;
    QSpacerItem *spacerItem;
    QWidget *tabGroups;
    QVBoxLayout *vboxLayout2;
    QHBoxLayout *hboxLayout4;
    QLabel *textLabel2_2_2;
    KColorButton *kcfg_group_1;
    QHBoxLayout *hboxLayout5;
    QLabel *textLabel8;
    KColorButton *kcfg_group_2;
    QHBoxLayout *hboxLayout6;
    QLabel *textLabel7;
    KColorButton *kcfg_group_3;
    QHBoxLayout *hboxLayout7;
    QLabel *textLabel6;
    KColorButton *kcfg_group_4;
    QHBoxLayout *hboxLayout8;
    QLabel *textLabel5_2;
    KColorButton *kcfg_group_5;
    QHBoxLayout *hboxLayout9;
    QLabel *textLabel4_2;
    KColorButton *kcfg_group_6;
    QHBoxLayout *hboxLayout10;
    QLabel *textLabel3_2;
    KColorButton *kcfg_group_7;
    QHBoxLayout *hboxLayout11;
    QLabel *textLabel2_2;
    KColorButton *kcfg_group_8;
    QSpacerItem *spacerItem1;
    QWidget *tabStateOfMatter;
    QVBoxLayout *vboxLayout3;
    QHBoxLayout *hboxLayout12;
    QLabel *textLabel1;
    KColorButton *kcfg_color_solid;
    QHBoxLayout *hboxLayout13;
    QLabel *textLabel2;
    KColorButton *kcfg_color_liquid;
    QHBoxLayout *hboxLayout14;
    QLabel *textLabel3;
    KColorButton *kcfg_color_vapor;
    QSpacerItem *spacerItem2;
    QWidget *tabFamily;
    QVBoxLayout *vboxLayout4;
    QHBoxLayout *hboxLayout15;
    QLabel *textLabel2_2_2_2;
    KColorButton *kcfg_alkali_metal;
    QHBoxLayout *hboxLayout16;
    QLabel *textLabel8_2;
    KColorButton *kcfg_rare;
    QHBoxLayout *hboxLayout17;
    QLabel *textLabel7_2;
    KColorButton *kcfg_nonmetal;
    QHBoxLayout *hboxLayout18;
    QLabel *textLabel6_2;
    KColorButton *kcfg_alkaline_earth_metal;
    QHBoxLayout *hboxLayout19;
    QLabel *textLabel5_2_2;
    KColorButton *kcfg_other_metal;
    QHBoxLayout *hboxLayout20;
    QLabel *textLabel4_2_2;
    KColorButton *kcfg_halogene;
    QHBoxLayout *hboxLayout21;
    QLabel *textLabel3_2_2;
    KColorButton *kcfg_transition;
    QHBoxLayout *hboxLayout22;
    QLabel *textLabel2_2_3;
    KColorButton *kcfg_noble_gas;
    QHBoxLayout *hboxLayout23;
    QLabel *textLabel2_2_3_2;
    KColorButton *kcfg_metalloid;
    QSpacerItem *spacerItem3;
    QWidget *tabNoColor;
    QVBoxLayout *vboxLayout5;
    QHBoxLayout *hboxLayout24;
    QLabel *textLabel8_2_2;
    KColorButton *kcfg_noscheme;
    QSpacerItem *spacerItem4;

    void setupUi(QWidget *setupColors)
    {
        if (setupColors->objectName().isEmpty())
            setupColors->setObjectName("setupColors");
        setupColors->resize(627, 418);
        vboxLayout = new QVBoxLayout(setupColors);
        vboxLayout->setSpacing(0);
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        vboxLayout->setObjectName("vboxLayout");
        dfgdfg = new QTabWidget(setupColors);
        dfgdfg->setObjectName("dfgdfg");
        dfgdfg->setDocumentMode(true);
        tabBlocks = new QWidget();
        tabBlocks->setObjectName("tabBlocks");
        vboxLayout1 = new QVBoxLayout(tabBlocks);
#ifndef UI_Q_OS_MAC
        vboxLayout1->setSpacing(6);
#endif
        vboxLayout1->setContentsMargins(8, 8, 8, 8);
        vboxLayout1->setObjectName("vboxLayout1");
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName("hboxLayout");
        textLabel13 = new QLabel(tabBlocks);
        textLabel13->setObjectName("textLabel13");

        hboxLayout->addWidget(textLabel13);

        kcfg_block_s = new KColorButton(tabBlocks);
        kcfg_block_s->setObjectName("kcfg_block_s");

        hboxLayout->addWidget(kcfg_block_s);


        vboxLayout1->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout1->setSpacing(6);
#endif
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName("hboxLayout1");
        textLabel14 = new QLabel(tabBlocks);
        textLabel14->setObjectName("textLabel14");

        hboxLayout1->addWidget(textLabel14);

        kcfg_block_p = new KColorButton(tabBlocks);
        kcfg_block_p->setObjectName("kcfg_block_p");

        hboxLayout1->addWidget(kcfg_block_p);


        vboxLayout1->addLayout(hboxLayout1);

        hboxLayout2 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout2->setSpacing(6);
#endif
        hboxLayout2->setContentsMargins(0, 0, 0, 0);
        hboxLayout2->setObjectName("hboxLayout2");
        textLabel15 = new QLabel(tabBlocks);
        textLabel15->setObjectName("textLabel15");

        hboxLayout2->addWidget(textLabel15);

        kcfg_block_d = new KColorButton(tabBlocks);
        kcfg_block_d->setObjectName("kcfg_block_d");

        hboxLayout2->addWidget(kcfg_block_d);


        vboxLayout1->addLayout(hboxLayout2);

        hboxLayout3 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout3->setSpacing(6);
#endif
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        hboxLayout3->setObjectName("hboxLayout3");
        textLabel16 = new QLabel(tabBlocks);
        textLabel16->setObjectName("textLabel16");

        hboxLayout3->addWidget(textLabel16);

        kcfg_block_f = new KColorButton(tabBlocks);
        kcfg_block_f->setObjectName("kcfg_block_f");

        hboxLayout3->addWidget(kcfg_block_f);


        vboxLayout1->addLayout(hboxLayout3);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout1->addItem(spacerItem);

        dfgdfg->addTab(tabBlocks, QString());
        tabGroups = new QWidget();
        tabGroups->setObjectName("tabGroups");
        vboxLayout2 = new QVBoxLayout(tabGroups);
#ifndef UI_Q_OS_MAC
        vboxLayout2->setSpacing(6);
#endif
        vboxLayout2->setContentsMargins(8, 8, 8, 8);
        vboxLayout2->setObjectName("vboxLayout2");
        hboxLayout4 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout4->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout4->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout4->setObjectName("hboxLayout4");
        textLabel2_2_2 = new QLabel(tabGroups);
        textLabel2_2_2->setObjectName("textLabel2_2_2");

        hboxLayout4->addWidget(textLabel2_2_2);

        kcfg_group_1 = new KColorButton(tabGroups);
        kcfg_group_1->setObjectName("kcfg_group_1");

        hboxLayout4->addWidget(kcfg_group_1);


        vboxLayout2->addLayout(hboxLayout4);

        hboxLayout5 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout5->setSpacing(6);
#endif
        hboxLayout5->setContentsMargins(0, 0, 0, 0);
        hboxLayout5->setObjectName("hboxLayout5");
        textLabel8 = new QLabel(tabGroups);
        textLabel8->setObjectName("textLabel8");

        hboxLayout5->addWidget(textLabel8);

        kcfg_group_2 = new KColorButton(tabGroups);
        kcfg_group_2->setObjectName("kcfg_group_2");

        hboxLayout5->addWidget(kcfg_group_2);


        vboxLayout2->addLayout(hboxLayout5);

        hboxLayout6 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout6->setSpacing(6);
#endif
        hboxLayout6->setContentsMargins(0, 0, 0, 0);
        hboxLayout6->setObjectName("hboxLayout6");
        textLabel7 = new QLabel(tabGroups);
        textLabel7->setObjectName("textLabel7");

        hboxLayout6->addWidget(textLabel7);

        kcfg_group_3 = new KColorButton(tabGroups);
        kcfg_group_3->setObjectName("kcfg_group_3");

        hboxLayout6->addWidget(kcfg_group_3);


        vboxLayout2->addLayout(hboxLayout6);

        hboxLayout7 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout7->setSpacing(6);
#endif
        hboxLayout7->setContentsMargins(0, 0, 0, 0);
        hboxLayout7->setObjectName("hboxLayout7");
        textLabel6 = new QLabel(tabGroups);
        textLabel6->setObjectName("textLabel6");

        hboxLayout7->addWidget(textLabel6);

        kcfg_group_4 = new KColorButton(tabGroups);
        kcfg_group_4->setObjectName("kcfg_group_4");

        hboxLayout7->addWidget(kcfg_group_4);


        vboxLayout2->addLayout(hboxLayout7);

        hboxLayout8 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout8->setSpacing(6);
#endif
        hboxLayout8->setContentsMargins(0, 0, 0, 0);
        hboxLayout8->setObjectName("hboxLayout8");
        textLabel5_2 = new QLabel(tabGroups);
        textLabel5_2->setObjectName("textLabel5_2");

        hboxLayout8->addWidget(textLabel5_2);

        kcfg_group_5 = new KColorButton(tabGroups);
        kcfg_group_5->setObjectName("kcfg_group_5");

        hboxLayout8->addWidget(kcfg_group_5);


        vboxLayout2->addLayout(hboxLayout8);

        hboxLayout9 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout9->setSpacing(6);
#endif
        hboxLayout9->setContentsMargins(0, 0, 0, 0);
        hboxLayout9->setObjectName("hboxLayout9");
        textLabel4_2 = new QLabel(tabGroups);
        textLabel4_2->setObjectName("textLabel4_2");

        hboxLayout9->addWidget(textLabel4_2);

        kcfg_group_6 = new KColorButton(tabGroups);
        kcfg_group_6->setObjectName("kcfg_group_6");

        hboxLayout9->addWidget(kcfg_group_6);


        vboxLayout2->addLayout(hboxLayout9);

        hboxLayout10 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout10->setSpacing(6);
#endif
        hboxLayout10->setContentsMargins(0, 0, 0, 0);
        hboxLayout10->setObjectName("hboxLayout10");
        textLabel3_2 = new QLabel(tabGroups);
        textLabel3_2->setObjectName("textLabel3_2");

        hboxLayout10->addWidget(textLabel3_2);

        kcfg_group_7 = new KColorButton(tabGroups);
        kcfg_group_7->setObjectName("kcfg_group_7");

        hboxLayout10->addWidget(kcfg_group_7);


        vboxLayout2->addLayout(hboxLayout10);

        hboxLayout11 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout11->setSpacing(6);
#endif
        hboxLayout11->setContentsMargins(0, 0, 0, 0);
        hboxLayout11->setObjectName("hboxLayout11");
        textLabel2_2 = new QLabel(tabGroups);
        textLabel2_2->setObjectName("textLabel2_2");

        hboxLayout11->addWidget(textLabel2_2);

        kcfg_group_8 = new KColorButton(tabGroups);
        kcfg_group_8->setObjectName("kcfg_group_8");

        hboxLayout11->addWidget(kcfg_group_8);


        vboxLayout2->addLayout(hboxLayout11);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout2->addItem(spacerItem1);

        dfgdfg->addTab(tabGroups, QString());
        tabStateOfMatter = new QWidget();
        tabStateOfMatter->setObjectName("tabStateOfMatter");
        vboxLayout3 = new QVBoxLayout(tabStateOfMatter);
#ifndef UI_Q_OS_MAC
        vboxLayout3->setSpacing(6);
#endif
        vboxLayout3->setContentsMargins(8, 8, 8, 8);
        vboxLayout3->setObjectName("vboxLayout3");
        hboxLayout12 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout12->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout12->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout12->setObjectName("hboxLayout12");
        textLabel1 = new QLabel(tabStateOfMatter);
        textLabel1->setObjectName("textLabel1");

        hboxLayout12->addWidget(textLabel1);

        kcfg_color_solid = new KColorButton(tabStateOfMatter);
        kcfg_color_solid->setObjectName("kcfg_color_solid");

        hboxLayout12->addWidget(kcfg_color_solid);


        vboxLayout3->addLayout(hboxLayout12);

        hboxLayout13 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout13->setSpacing(6);
#endif
        hboxLayout13->setContentsMargins(0, 0, 0, 0);
        hboxLayout13->setObjectName("hboxLayout13");
        textLabel2 = new QLabel(tabStateOfMatter);
        textLabel2->setObjectName("textLabel2");

        hboxLayout13->addWidget(textLabel2);

        kcfg_color_liquid = new KColorButton(tabStateOfMatter);
        kcfg_color_liquid->setObjectName("kcfg_color_liquid");

        hboxLayout13->addWidget(kcfg_color_liquid);


        vboxLayout3->addLayout(hboxLayout13);

        hboxLayout14 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout14->setSpacing(6);
#endif
        hboxLayout14->setContentsMargins(0, 0, 0, 0);
        hboxLayout14->setObjectName("hboxLayout14");
        textLabel3 = new QLabel(tabStateOfMatter);
        textLabel3->setObjectName("textLabel3");

        hboxLayout14->addWidget(textLabel3);

        kcfg_color_vapor = new KColorButton(tabStateOfMatter);
        kcfg_color_vapor->setObjectName("kcfg_color_vapor");

        hboxLayout14->addWidget(kcfg_color_vapor);


        vboxLayout3->addLayout(hboxLayout14);

        spacerItem2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout3->addItem(spacerItem2);

        dfgdfg->addTab(tabStateOfMatter, QString());
        tabFamily = new QWidget();
        tabFamily->setObjectName("tabFamily");
        vboxLayout4 = new QVBoxLayout(tabFamily);
#ifndef UI_Q_OS_MAC
        vboxLayout4->setSpacing(6);
#endif
        vboxLayout4->setContentsMargins(8, 8, 8, 8);
        vboxLayout4->setObjectName("vboxLayout4");
        hboxLayout15 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout15->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout15->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout15->setObjectName("hboxLayout15");
        textLabel2_2_2_2 = new QLabel(tabFamily);
        textLabel2_2_2_2->setObjectName("textLabel2_2_2_2");

        hboxLayout15->addWidget(textLabel2_2_2_2);

        kcfg_alkali_metal = new KColorButton(tabFamily);
        kcfg_alkali_metal->setObjectName("kcfg_alkali_metal");

        hboxLayout15->addWidget(kcfg_alkali_metal);


        vboxLayout4->addLayout(hboxLayout15);

        hboxLayout16 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout16->setSpacing(6);
#endif
        hboxLayout16->setContentsMargins(0, 0, 0, 0);
        hboxLayout16->setObjectName("hboxLayout16");
        textLabel8_2 = new QLabel(tabFamily);
        textLabel8_2->setObjectName("textLabel8_2");

        hboxLayout16->addWidget(textLabel8_2);

        kcfg_rare = new KColorButton(tabFamily);
        kcfg_rare->setObjectName("kcfg_rare");

        hboxLayout16->addWidget(kcfg_rare);


        vboxLayout4->addLayout(hboxLayout16);

        hboxLayout17 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout17->setSpacing(6);
#endif
        hboxLayout17->setContentsMargins(0, 0, 0, 0);
        hboxLayout17->setObjectName("hboxLayout17");
        textLabel7_2 = new QLabel(tabFamily);
        textLabel7_2->setObjectName("textLabel7_2");

        hboxLayout17->addWidget(textLabel7_2);

        kcfg_nonmetal = new KColorButton(tabFamily);
        kcfg_nonmetal->setObjectName("kcfg_nonmetal");

        hboxLayout17->addWidget(kcfg_nonmetal);


        vboxLayout4->addLayout(hboxLayout17);

        hboxLayout18 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout18->setSpacing(6);
#endif
        hboxLayout18->setContentsMargins(0, 0, 0, 0);
        hboxLayout18->setObjectName("hboxLayout18");
        textLabel6_2 = new QLabel(tabFamily);
        textLabel6_2->setObjectName("textLabel6_2");

        hboxLayout18->addWidget(textLabel6_2);

        kcfg_alkaline_earth_metal = new KColorButton(tabFamily);
        kcfg_alkaline_earth_metal->setObjectName("kcfg_alkaline_earth_metal");

        hboxLayout18->addWidget(kcfg_alkaline_earth_metal);


        vboxLayout4->addLayout(hboxLayout18);

        hboxLayout19 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout19->setSpacing(6);
#endif
        hboxLayout19->setContentsMargins(0, 0, 0, 0);
        hboxLayout19->setObjectName("hboxLayout19");
        textLabel5_2_2 = new QLabel(tabFamily);
        textLabel5_2_2->setObjectName("textLabel5_2_2");

        hboxLayout19->addWidget(textLabel5_2_2);

        kcfg_other_metal = new KColorButton(tabFamily);
        kcfg_other_metal->setObjectName("kcfg_other_metal");

        hboxLayout19->addWidget(kcfg_other_metal);


        vboxLayout4->addLayout(hboxLayout19);

        hboxLayout20 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout20->setSpacing(6);
#endif
        hboxLayout20->setContentsMargins(0, 0, 0, 0);
        hboxLayout20->setObjectName("hboxLayout20");
        textLabel4_2_2 = new QLabel(tabFamily);
        textLabel4_2_2->setObjectName("textLabel4_2_2");

        hboxLayout20->addWidget(textLabel4_2_2);

        kcfg_halogene = new KColorButton(tabFamily);
        kcfg_halogene->setObjectName("kcfg_halogene");

        hboxLayout20->addWidget(kcfg_halogene);


        vboxLayout4->addLayout(hboxLayout20);

        hboxLayout21 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout21->setSpacing(6);
#endif
        hboxLayout21->setContentsMargins(0, 0, 0, 0);
        hboxLayout21->setObjectName("hboxLayout21");
        textLabel3_2_2 = new QLabel(tabFamily);
        textLabel3_2_2->setObjectName("textLabel3_2_2");

        hboxLayout21->addWidget(textLabel3_2_2);

        kcfg_transition = new KColorButton(tabFamily);
        kcfg_transition->setObjectName("kcfg_transition");

        hboxLayout21->addWidget(kcfg_transition);


        vboxLayout4->addLayout(hboxLayout21);

        hboxLayout22 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout22->setSpacing(6);
#endif
        hboxLayout22->setContentsMargins(0, 0, 0, 0);
        hboxLayout22->setObjectName("hboxLayout22");
        textLabel2_2_3 = new QLabel(tabFamily);
        textLabel2_2_3->setObjectName("textLabel2_2_3");

        hboxLayout22->addWidget(textLabel2_2_3);

        kcfg_noble_gas = new KColorButton(tabFamily);
        kcfg_noble_gas->setObjectName("kcfg_noble_gas");

        hboxLayout22->addWidget(kcfg_noble_gas);


        vboxLayout4->addLayout(hboxLayout22);

        hboxLayout23 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout23->setSpacing(6);
#endif
        hboxLayout23->setContentsMargins(0, 0, 0, 0);
        hboxLayout23->setObjectName("hboxLayout23");
        textLabel2_2_3_2 = new QLabel(tabFamily);
        textLabel2_2_3_2->setObjectName("textLabel2_2_3_2");

        hboxLayout23->addWidget(textLabel2_2_3_2);

        kcfg_metalloid = new KColorButton(tabFamily);
        kcfg_metalloid->setObjectName("kcfg_metalloid");

        hboxLayout23->addWidget(kcfg_metalloid);


        vboxLayout4->addLayout(hboxLayout23);

        spacerItem3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout4->addItem(spacerItem3);

        dfgdfg->addTab(tabFamily, QString());
        tabNoColor = new QWidget();
        tabNoColor->setObjectName("tabNoColor");
        vboxLayout5 = new QVBoxLayout(tabNoColor);
#ifndef UI_Q_OS_MAC
        vboxLayout5->setSpacing(6);
#endif
        vboxLayout5->setContentsMargins(8, 8, 8, 8);
        vboxLayout5->setObjectName("vboxLayout5");
        hboxLayout24 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout24->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        hboxLayout24->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout24->setObjectName("hboxLayout24");
        textLabel8_2_2 = new QLabel(tabNoColor);
        textLabel8_2_2->setObjectName("textLabel8_2_2");

        hboxLayout24->addWidget(textLabel8_2_2);

        kcfg_noscheme = new KColorButton(tabNoColor);
        kcfg_noscheme->setObjectName("kcfg_noscheme");

        hboxLayout24->addWidget(kcfg_noscheme);


        vboxLayout5->addLayout(hboxLayout24);

        spacerItem4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout5->addItem(spacerItem4);

        dfgdfg->addTab(tabNoColor, QString());

        vboxLayout->addWidget(dfgdfg);


        retranslateUi(setupColors);

        dfgdfg->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(setupColors);
    } // setupUi

    void retranslateUi(QWidget *setupColors)
    {
        textLabel13->setText(tr2i18n("s-Block:", nullptr));
        textLabel14->setText(tr2i18n("p-Block:", nullptr));
        textLabel15->setText(tr2i18n("d-Block:", nullptr));
        textLabel16->setText(tr2i18n("f-Block:", nullptr));
        dfgdfg->setTabText(dfgdfg->indexOf(tabBlocks), tr2i18n("Blocks", nullptr));
        textLabel2_2_2->setText(tr2i18n("Group 1:", nullptr));
        textLabel8->setText(tr2i18n("Group 2:", nullptr));
        textLabel7->setText(tr2i18n("Group 3:", nullptr));
        textLabel6->setText(tr2i18n("Group 4:", nullptr));
        textLabel5_2->setText(tr2i18n("Group 5:", nullptr));
        textLabel4_2->setText(tr2i18n("Group 6:", nullptr));
        textLabel3_2->setText(tr2i18n("Group 7:", nullptr));
        textLabel2_2->setText(tr2i18n("Group 8:", nullptr));
        dfgdfg->setTabText(dfgdfg->indexOf(tabGroups), tr2i18n("Groups", nullptr));
        textLabel1->setText(tr2i18n("Solid:", nullptr));
        textLabel2->setText(tr2i18n("Liquid:", nullptr));
        textLabel3->setText(tr2i18n("Vaporous:", nullptr));
        dfgdfg->setTabText(dfgdfg->indexOf(tabStateOfMatter), tr2i18n("State of Matter", nullptr));
        textLabel2_2_2_2->setText(tr2i18n("Alkali metals:", nullptr));
        textLabel8_2->setText(tr2i18n("Rare earth:", nullptr));
        textLabel7_2->setText(tr2i18n("Non-metals:", nullptr));
        textLabel6_2->setText(tr2i18n("Alkaline earth metals:", nullptr));
        textLabel5_2_2->setText(tr2i18n("Other metals:", nullptr));
        textLabel4_2_2->setText(tr2i18n("Halogens:", nullptr));
        textLabel3_2_2->setText(tr2i18n("Transition metals:", nullptr));
        textLabel2_2_3->setText(tr2i18n("Noble gases:", nullptr));
        textLabel2_2_3_2->setText(tr2i18n("Metalloids:", nullptr));
        dfgdfg->setTabText(dfgdfg->indexOf(tabFamily), tr2i18n("Family", nullptr));
        textLabel8_2_2->setText(tr2i18n("All the elements:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_noscheme->setToolTip(tr2i18n("This color will be used if no other scheme is selected", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_noscheme->setWhatsThis(tr2i18n("This color will be used if no other scheme is selected", nullptr));
#endif // QT_CONFIG(whatsthis)
        dfgdfg->setTabText(dfgdfg->indexOf(tabNoColor), tr2i18n("No Color Scheme", nullptr));
        (void)setupColors;
    } // retranslateUi

};

namespace Ui {
    class setupColors: public Ui_setupColors {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGS_COLORS_H

