/********************************************************************************
** Form generated from reading UI file 'concCalculator.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONCCALCULATOR_H
#define UI_CONCCALCULATOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "ktextedit.h"

QT_BEGIN_NAMESPACE

class Ui_concCalculator
{
public:
    QVBoxLayout *verticalLayout_2;
    KTextEdit *ktextedit;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *label_36;
    QDoubleSpinBox *amtSolute;
    KComboBox *amtSltType;
    QLabel *label_39;
    QDoubleSpinBox *molarMass;
    QLabel *label_40;
    QDoubleSpinBox *eqtMass;
    QLabel *label_52;
    QDoubleSpinBox *densitySolute;
    QLabel *label_31;
    QDoubleSpinBox *amtSolvent;
    KComboBox *amtSlvtType;
    QLabel *label_42;
    QDoubleSpinBox *molarMassSolvent;
    QLabel *label_55;
    QDoubleSpinBox *densitySolvent;
    QLabel *label_41;
    QDoubleSpinBox *concentration;
    QLabel *label_37;
    KComboBox *mode;
    QSpacerItem *horizontalSpacer;
    KComboBox *densSlvt_unit;
    KComboBox *conc_unit;
    KComboBox *amtSlvt_unit;
    QLabel *label_19;
    KComboBox *densSlt_unit;
    KComboBox *amtSlt_unit;
    QLabel *label_17;
    QLabel *label_18;
    QSpacerItem *horizontalSpacer_2;
    QLabel *error;
    QSpacerItem *verticalSpacer_4;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer_4;
    QPushButton *reset;

    void setupUi(QWidget *concCalculator)
    {
        if (concCalculator->objectName().isEmpty())
            concCalculator->setObjectName("concCalculator");
        concCalculator->setEnabled(true);
        concCalculator->resize(706, 465);
        verticalLayout_2 = new QVBoxLayout(concCalculator);
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        ktextedit = new KTextEdit(concCalculator);
        ktextedit->setObjectName("ktextedit");
        ktextedit->setReadOnly(true);

        verticalLayout_2->addWidget(ktextedit);

        groupBox = new QGroupBox(concCalculator);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        label_36 = new QLabel(groupBox);
        label_36->setObjectName("label_36");
        label_36->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_36, 1, 0, 1, 1);

        amtSolute = new QDoubleSpinBox(groupBox);
        amtSolute->setObjectName("amtSolute");
        amtSolute->setDecimals(4);
        amtSolute->setMaximum(1000000000.000000000000000);

        gridLayout->addWidget(amtSolute, 1, 1, 1, 1);

        amtSltType = new KComboBox(groupBox);
        amtSltType->setObjectName("amtSltType");

        gridLayout->addWidget(amtSltType, 1, 3, 1, 1);

        label_39 = new QLabel(groupBox);
        label_39->setObjectName("label_39");
        label_39->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_39, 2, 0, 1, 1);

        molarMass = new QDoubleSpinBox(groupBox);
        molarMass->setObjectName("molarMass");
        molarMass->setDecimals(4);
        molarMass->setMaximum(1000000000.000000000000000);

        gridLayout->addWidget(molarMass, 2, 1, 1, 1);

        label_40 = new QLabel(groupBox);
        label_40->setObjectName("label_40");
        label_40->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_40, 3, 0, 1, 1);

        eqtMass = new QDoubleSpinBox(groupBox);
        eqtMass->setObjectName("eqtMass");
        eqtMass->setDecimals(4);
        eqtMass->setMaximum(1000000000.000000000000000);

        gridLayout->addWidget(eqtMass, 3, 1, 1, 1);

        label_52 = new QLabel(groupBox);
        label_52->setObjectName("label_52");
        label_52->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_52, 4, 0, 1, 1);

        densitySolute = new QDoubleSpinBox(groupBox);
        densitySolute->setObjectName("densitySolute");
        densitySolute->setDecimals(4);
        densitySolute->setMaximum(1000000000.000000000000000);

        gridLayout->addWidget(densitySolute, 4, 1, 1, 1);

        label_31 = new QLabel(groupBox);
        label_31->setObjectName("label_31");
        label_31->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_31, 5, 0, 1, 1);

        amtSolvent = new QDoubleSpinBox(groupBox);
        amtSolvent->setObjectName("amtSolvent");
        amtSolvent->setDecimals(4);
        amtSolvent->setMaximum(1000000000.000000000000000);

        gridLayout->addWidget(amtSolvent, 5, 1, 1, 1);

        amtSlvtType = new KComboBox(groupBox);
        amtSlvtType->setObjectName("amtSlvtType");

        gridLayout->addWidget(amtSlvtType, 5, 3, 1, 1);

        label_42 = new QLabel(groupBox);
        label_42->setObjectName("label_42");
        label_42->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_42, 6, 0, 1, 1);

        molarMassSolvent = new QDoubleSpinBox(groupBox);
        molarMassSolvent->setObjectName("molarMassSolvent");
        molarMassSolvent->setDecimals(4);
        molarMassSolvent->setMaximum(1000000000.000000000000000);

        gridLayout->addWidget(molarMassSolvent, 6, 1, 1, 1);

        label_55 = new QLabel(groupBox);
        label_55->setObjectName("label_55");
        label_55->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_55, 7, 0, 1, 1);

        densitySolvent = new QDoubleSpinBox(groupBox);
        densitySolvent->setObjectName("densitySolvent");
        densitySolvent->setDecimals(4);
        densitySolvent->setMaximum(1000000000.000000000000000);

        gridLayout->addWidget(densitySolvent, 7, 1, 1, 1);

        label_41 = new QLabel(groupBox);
        label_41->setObjectName("label_41");
        label_41->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_41, 8, 0, 1, 1);

        concentration = new QDoubleSpinBox(groupBox);
        concentration->setObjectName("concentration");
        concentration->setDecimals(4);
        concentration->setMaximum(1000000000.000000000000000);

        gridLayout->addWidget(concentration, 8, 1, 1, 1);

        label_37 = new QLabel(groupBox);
        label_37->setObjectName("label_37");
        label_37->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_37, 0, 0, 1, 1);

        mode = new KComboBox(groupBox);
        mode->setObjectName("mode");

        gridLayout->addWidget(mode, 0, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 5, 1, 1);

        densSlvt_unit = new KComboBox(groupBox);
        densSlvt_unit->setObjectName("densSlvt_unit");

        gridLayout->addWidget(densSlvt_unit, 7, 2, 1, 1);

        conc_unit = new KComboBox(groupBox);
        conc_unit->setObjectName("conc_unit");

        gridLayout->addWidget(conc_unit, 8, 2, 1, 1);

        amtSlvt_unit = new KComboBox(groupBox);
        amtSlvt_unit->setObjectName("amtSlvt_unit");

        gridLayout->addWidget(amtSlvt_unit, 5, 2, 1, 1);

        label_19 = new QLabel(groupBox);
        label_19->setObjectName("label_19");
        label_19->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(label_19, 6, 2, 1, 1);

        densSlt_unit = new KComboBox(groupBox);
        densSlt_unit->setObjectName("densSlt_unit");

        gridLayout->addWidget(densSlt_unit, 4, 2, 1, 1);

        amtSlt_unit = new KComboBox(groupBox);
        amtSlt_unit->setObjectName("amtSlt_unit");

        gridLayout->addWidget(amtSlt_unit, 1, 2, 1, 1);

        label_17 = new QLabel(groupBox);
        label_17->setObjectName("label_17");
        label_17->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(label_17, 2, 2, 1, 1);

        label_18 = new QLabel(groupBox);
        label_18->setObjectName("label_18");
        label_18->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(label_18, 3, 2, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 1, 6, 1, 1);


        verticalLayout_2->addWidget(groupBox);

        error = new QLabel(concCalculator);
        error->setObjectName("error");

        verticalLayout_2->addWidget(error);

        verticalSpacer_4 = new QSpacerItem(20, 232, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_4);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_4);

        reset = new QPushButton(concCalculator);
        reset->setObjectName("reset");

        horizontalLayout_4->addWidget(reset);


        verticalLayout_2->addLayout(horizontalLayout_4);


        retranslateUi(concCalculator);

        mode->setCurrentIndex(5);


        QMetaObject::connectSlotsByName(concCalculator);
    } // setupUi

    void retranslateUi(QWidget *concCalculator)
    {
        ktextedit->setHtml(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Liberation Sans'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:12pt; font-weight:600;\">Some of the following data is not necessary. For instance, if you specify the amount of solute in moles, you do not have to specify the molar mass of the solute.</span></p></body></html>", nullptr));
        groupBox->setTitle(tr2i18n("Data", nullptr));
        label_36->setText(tr2i18n("<big><b>Amount of solute:</b></big>", nullptr));
#if QT_CONFIG(tooltip)
        amtSolute->setToolTip(tr2i18n("<big>Specify the amount of solute</big>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        amtSolute->setWhatsThis(tr2i18n("This is the box used to specify the amount of solute in the solution.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        amtSltType->setToolTip(tr2i18n("The method by which you want to specify the amount of solute", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        amtSltType->setWhatsThis(tr2i18n("This box is used to change the mode in which the amount of solute is specified, i.e. mass, moles or volume.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_39->setText(tr2i18n("<big><b>Molar mass of solute:</b></big>", nullptr));
#if QT_CONFIG(tooltip)
        molarMass->setToolTip(tr2i18n("<big>Specify the molar mass of the solute</big>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        molarMass->setWhatsThis(tr2i18n("This box is used to specify the molar mass of the substance.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_40->setText(tr2i18n("<big><b>Equivalent mass of solute:</b></big>", nullptr));
#if QT_CONFIG(tooltip)
        eqtMass->setToolTip(tr2i18n("<big>Specify the equivalent mass of the solute</big>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        eqtMass->setWhatsThis(tr2i18n("This box is used to specify the equivalent mass of the solute. This is required only if concentration in terms of normality is involved.\n"
"Normality = Number of Equivalents / liter of solution", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_52->setText(tr2i18n("<big><b>Density of solute:</b></big>", nullptr));
#if QT_CONFIG(tooltip)
        densitySolute->setToolTip(tr2i18n("<big>Specify the density of the solute</big>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        densitySolute->setWhatsThis(tr2i18n("This box is used to specify the value of the density of the solute. This is required only if you are specifying the amount of solute in terms of volume.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_31->setText(tr2i18n("<big><b>Amount of Solvent:</b></big>", nullptr));
#if QT_CONFIG(tooltip)
        amtSolvent->setToolTip(tr2i18n("<big>Specify the amount of solvent</big>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        amtSolvent->setWhatsThis(tr2i18n("This box is used to specify the amount of solvent in the solution.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        amtSlvtType->setToolTip(tr2i18n("<big>The method by which you want to specify volume</big>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        amtSlvtType->setWhatsThis(tr2i18n("This box is used to change the mode in which amount of solvent is specified, i.e. mass, moles or volume.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_42->setText(tr2i18n("<big><b>Molar mass of solvent:</b></big>", nullptr));
#if QT_CONFIG(tooltip)
        molarMassSolvent->setToolTip(tr2i18n("<big>Specify the molar mass of the solvent</big>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        molarMassSolvent->setWhatsThis(tr2i18n("This box is used to specify the molar mass of the solvent.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_55->setText(tr2i18n("<big><b>Density of Solvent:</b></big>", nullptr));
#if QT_CONFIG(tooltip)
        densitySolvent->setToolTip(tr2i18n("<big>Specify the density of the solvent</big>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        densitySolvent->setWhatsThis(tr2i18n("This box is used to specify the density of the solution and is required only if the amount of solution is specified/needed in terms of mass.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_41->setText(tr2i18n("<big><b>Concentration:</b></big>", nullptr));
#if QT_CONFIG(tooltip)
        concentration->setToolTip(tr2i18n("<big>Specify the concentration of the solution</big>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        concentration->setWhatsThis(tr2i18n("This box is used to specify the concentration of the solution in respective units to the right.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_37->setText(tr2i18n("<big><b>Calculate:</b></big>", nullptr));
#if QT_CONFIG(tooltip)
        mode->setToolTip(tr2i18n("<big>Specify what you want to calculate</big>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mode->setWhatsThis(tr2i18n("This is the list of quantities that you can calculate. Choose one of the quantities and specify the other required values to calculate it.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        densSlvt_unit->setToolTip(tr2i18n("Specify the units for density of solvent", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        conc_unit->setToolTip(tr2i18n("<big>Specify the unit/method for specifying concentration</big>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        amtSlvt_unit->setToolTip(tr2i18n("<big>The units for amount of solvent</big>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        amtSlvt_unit->setWhatsThis(tr2i18n("This box is used to specify the units for the amount of solvent in the solution.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        label_19->setToolTip(tr2i18n("<big>The units for molar mass of solvent</big>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_19->setText(tr2i18n("(g/mole)", nullptr));
#if QT_CONFIG(tooltip)
        densSlt_unit->setToolTip(tr2i18n("<big>Specify the units of density</big>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        densSlt_unit->setWhatsThis(tr2i18n("This box is used to specify the units of the density of the solute. This is required only if you are specifying the amount of solute in terms of volume.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        amtSlt_unit->setToolTip(tr2i18n("<big>Specify the units for the amount of solute</big>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        amtSlt_unit->setWhatsThis(tr2i18n("This box is used to specify the units for the amount of solute in the solution.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        label_17->setToolTip(tr2i18n("<big>Units for molar mass of solute</big>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_17->setText(tr2i18n("(g/mol)", nullptr));
#if QT_CONFIG(tooltip)
        label_18->setToolTip(tr2i18n("<big>Units for equivalent mass of solute</big>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_18->setText(tr2i18n("(g/mole)", nullptr));
        error->setText(QString());
#if QT_CONFIG(tooltip)
        reset->setToolTip(tr2i18n("<big>Reset all values to initial values</big>", nullptr));
#endif // QT_CONFIG(tooltip)
        reset->setText(tr2i18n("Reset", nullptr));
        (void)concCalculator;
    } // retranslateUi

};

namespace Ui {
    class concCalculator: public Ui_concCalculator {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONCCALCULATOR_H

