/****************************************************************************
** Meta object code from reading C++ file 'concCalculator.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kalzium-26.08.0/src/calculator/concCalculator.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'concCalculator.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14concCalculatorE_t {};
} // unnamed namespace

template <> constexpr inline auto concCalculator::qt_create_metaobjectdata<qt_meta_tag_ZN14concCalculatorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "concCalculator",
        "calculateAmtSolute",
        "",
        "calculateAmtSolvent",
        "calculateMolarMass",
        "calculateEqtMass",
        "calculateMolarMassSolvent",
        "calculateConcentration",
        "amtSoluteChanged",
        "amtSoluteTypeChanged",
        "amtSolventChanged",
        "amtSolventTypeChanged",
        "molarMassChanged",
        "eqtMassChanged",
        "molarMassSolventChanged",
        "densitySoluteChanged",
        "densitySolventChanged",
        "concentrationChanged",
        "calculate",
        "volumeSolvent",
        "massSolvent",
        "molesSolvent",
        "densitySolvent",
        "volumeSolute",
        "massSolute",
        "molesSolute",
        "eqtsSolute",
        "densitySolute",
        "volumeUnitCombobox",
        "QComboBox*",
        "comboBox",
        "massUnitCombobox",
        "init",
        "error",
        "setMode"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'calculateAmtSolute'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'calculateAmtSolvent'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'calculateMolarMass'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'calculateEqtMass'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'calculateMolarMassSolvent'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'calculateConcentration'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'amtSoluteChanged'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'amtSoluteTypeChanged'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'amtSolventChanged'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'amtSolventTypeChanged'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'molarMassChanged'
        QtMocHelpers::SlotData<void(double)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'eqtMassChanged'
        QtMocHelpers::SlotData<void(double)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'molarMassSolventChanged'
        QtMocHelpers::SlotData<void(double)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 2 },
        }}),
        // Slot 'densitySoluteChanged'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'densitySolventChanged'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'concentrationChanged'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'calculate'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'volumeSolvent'
        QtMocHelpers::SlotData<double()>(19, 2, QMC::AccessPublic, QMetaType::Double),
        // Slot 'massSolvent'
        QtMocHelpers::SlotData<double()>(20, 2, QMC::AccessPublic, QMetaType::Double),
        // Slot 'molesSolvent'
        QtMocHelpers::SlotData<double()>(21, 2, QMC::AccessPublic, QMetaType::Double),
        // Slot 'densitySolvent'
        QtMocHelpers::SlotData<double()>(22, 2, QMC::AccessPublic, QMetaType::Double),
        // Slot 'volumeSolute'
        QtMocHelpers::SlotData<double()>(23, 2, QMC::AccessPublic, QMetaType::Double),
        // Slot 'massSolute'
        QtMocHelpers::SlotData<double()>(24, 2, QMC::AccessPublic, QMetaType::Double),
        // Slot 'molesSolute'
        QtMocHelpers::SlotData<double()>(25, 2, QMC::AccessPublic, QMetaType::Double),
        // Slot 'eqtsSolute'
        QtMocHelpers::SlotData<double()>(26, 2, QMC::AccessPublic, QMetaType::Double),
        // Slot 'densitySolute'
        QtMocHelpers::SlotData<double()>(27, 2, QMC::AccessPublic, QMetaType::Double),
        // Slot 'volumeUnitCombobox'
        QtMocHelpers::SlotData<void(QComboBox *)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'massUnitCombobox'
        QtMocHelpers::SlotData<void(QComboBox *)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'init'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'error'
        QtMocHelpers::SlotData<void(int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'setMode'
        QtMocHelpers::SlotData<void(int)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<concCalculator, qt_meta_tag_ZN14concCalculatorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject concCalculator::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14concCalculatorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14concCalculatorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14concCalculatorE_t>.metaTypes,
    nullptr
} };

void concCalculator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<concCalculator *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->calculateAmtSolute(); break;
        case 1: _t->calculateAmtSolvent(); break;
        case 2: _t->calculateMolarMass(); break;
        case 3: _t->calculateEqtMass(); break;
        case 4: _t->calculateMolarMassSolvent(); break;
        case 5: _t->calculateConcentration(); break;
        case 6: _t->amtSoluteChanged(); break;
        case 7: _t->amtSoluteTypeChanged(); break;
        case 8: _t->amtSolventChanged(); break;
        case 9: _t->amtSolventTypeChanged(); break;
        case 10: _t->molarMassChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 11: _t->eqtMassChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 12: _t->molarMassSolventChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 13: _t->densitySoluteChanged(); break;
        case 14: _t->densitySolventChanged(); break;
        case 15: _t->concentrationChanged(); break;
        case 16: _t->calculate(); break;
        case 17: { double _r = _t->volumeSolvent();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 18: { double _r = _t->massSolvent();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 19: { double _r = _t->molesSolvent();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 20: { double _r = _t->densitySolvent();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 21: { double _r = _t->volumeSolute();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 22: { double _r = _t->massSolute();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 23: { double _r = _t->molesSolute();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 24: { double _r = _t->eqtsSolute();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 25: { double _r = _t->densitySolute();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->volumeUnitCombobox((*reinterpret_cast<std::add_pointer_t<QComboBox*>>(_a[1]))); break;
        case 27: _t->massUnitCombobox((*reinterpret_cast<std::add_pointer_t<QComboBox*>>(_a[1]))); break;
        case 28: _t->init(); break;
        case 29: _t->error((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 30: _t->setMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *concCalculator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *concCalculator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14concCalculatorE_t>.strings))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int concCalculator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 31)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 31;
    }
    return _id;
}
QT_WARNING_POP
