/********************************************************************************
** Form generated from reading UI file 'spectrumview.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SPECTRUMVIEW_H
#define UI_SPECTRUMVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kalziumunitcombobox.h"
#include "spectrumwidget.h"

QT_BEGIN_NAMESPACE

class Ui_SpectrumView
{
public:
    QGridLayout *gridLayout;
    SpectrumWidget *m_spectrumWidget;
    QGridLayout *detailGridLayout;
    QLabel *label1;
    QSpinBox *minimumValue;
    QSpacerItem *verticalSpacer;
    QTreeWidget *peakListTable;
    QLabel *label2;
    QSpinBox *maximumValue;
    QGroupBox *groupBox;
    QGridLayout *gridLayout4;
    KalziumUnitCombobox *m_lengthUnit;
    QComboBox *m_spectrumType;
    QLabel *label;
    QLabel *label_2;
    QPushButton *btn_resetZoom;

    void setupUi(QWidget *SpectrumView)
    {
        if (SpectrumView->objectName().isEmpty())
            SpectrumView->setObjectName("SpectrumView");
        SpectrumView->resize(578, 413);
        gridLayout = new QGridLayout(SpectrumView);
#ifndef UI_Q_OS_MAC
        gridLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout->setContentsMargins(9, 9, 9, 9);
#endif
        gridLayout->setObjectName("gridLayout");
        m_spectrumWidget = new SpectrumWidget(SpectrumView);
        m_spectrumWidget->setObjectName("m_spectrumWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_spectrumWidget->sizePolicy().hasHeightForWidth());
        m_spectrumWidget->setSizePolicy(sizePolicy);
        m_spectrumWidget->setMinimumSize(QSize(0, 100));

        gridLayout->addWidget(m_spectrumWidget, 0, 0, 1, 4);

        detailGridLayout = new QGridLayout();
        detailGridLayout->setObjectName("detailGridLayout");
        label1 = new QLabel(SpectrumView);
        label1->setObjectName("label1");
        label1->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        detailGridLayout->addWidget(label1, 1, 0, 1, 1);

        minimumValue = new QSpinBox(SpectrumView);
        minimumValue->setObjectName("minimumValue");
        minimumValue->setMinimum(1);
        minimumValue->setMaximum(40000);
        minimumValue->setValue(3800);

        detailGridLayout->addWidget(minimumValue, 2, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        detailGridLayout->addItem(verticalSpacer, 4, 0, 1, 1);

        peakListTable = new QTreeWidget(SpectrumView);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QString::fromUtf8("1"));
        peakListTable->setHeaderItem(__qtreewidgetitem);
        peakListTable->setObjectName("peakListTable");

        detailGridLayout->addWidget(peakListTable, 1, 2, 6, 1);

        label2 = new QLabel(SpectrumView);
        label2->setObjectName("label2");
        label2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        detailGridLayout->addWidget(label2, 1, 1, 1, 1);

        maximumValue = new QSpinBox(SpectrumView);
        maximumValue->setObjectName("maximumValue");
        maximumValue->setMinimum(1);
        maximumValue->setMaximum(40000);
        maximumValue->setValue(7800);

        detailGridLayout->addWidget(maximumValue, 2, 1, 1, 1);

        groupBox = new QGroupBox(SpectrumView);
        groupBox->setObjectName("groupBox");
        gridLayout4 = new QGridLayout(groupBox);
        gridLayout4->setObjectName("gridLayout4");
        m_lengthUnit = new KalziumUnitCombobox(groupBox);
        m_lengthUnit->setObjectName("m_lengthUnit");

        gridLayout4->addWidget(m_lengthUnit, 0, 1, 1, 1);

        m_spectrumType = new QComboBox(groupBox);
        m_spectrumType->addItem(QString());
        m_spectrumType->addItem(QString());
        m_spectrumType->setObjectName("m_spectrumType");

        gridLayout4->addWidget(m_spectrumType, 1, 1, 1, 1);

        label = new QLabel(groupBox);
        label->setObjectName("label");

        gridLayout4->addWidget(label, 0, 0, 1, 1);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        gridLayout4->addWidget(label_2, 1, 0, 1, 1);


        detailGridLayout->addWidget(groupBox, 5, 0, 1, 2);

        btn_resetZoom = new QPushButton(SpectrumView);
        btn_resetZoom->setObjectName("btn_resetZoom");

        detailGridLayout->addWidget(btn_resetZoom, 3, 0, 1, 2);


        gridLayout->addLayout(detailGridLayout, 2, 1, 1, 1);

#if QT_CONFIG(shortcut)
        label1->setBuddy(minimumValue);
        label2->setBuddy(maximumValue);
#endif // QT_CONFIG(shortcut)

        retranslateUi(SpectrumView);

        QMetaObject::connectSlotsByName(SpectrumView);
    } // setupUi

    void retranslateUi(QWidget *SpectrumView)
    {
#if QT_CONFIG(tooltip)
        SpectrumView->setToolTip(tr2i18n("This page gives an overview of the spectrum of this element. Using the mouse you can zoom into the spectrum.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        SpectrumView->setWhatsThis(tr2i18n("This page gives an overview of the spectrum of this element.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        m_spectrumWidget->setToolTip(tr2i18n("This is the spectrum of the element.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        m_spectrumWidget->setWhatsThis(tr2i18n("This is the spectrum of the element.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label1->setText(tr2i18n("&Minimum value:", nullptr));
#if QT_CONFIG(tooltip)
        minimumValue->setToolTip(tr2i18n("This sets the leftmost wavelength of the spectrum.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        minimumValue->setWhatsThis(tr2i18n("This sets the leftmost wavelength of the spectrum.", nullptr));
#endif // QT_CONFIG(whatsthis)
        minimumValue->setSuffix(QString());
        label2->setText(tr2i18n("Maximum &value:", nullptr));
#if QT_CONFIG(tooltip)
        maximumValue->setToolTip(tr2i18n("This sets the rightmost wavelength of the spectrum.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        maximumValue->setWhatsThis(tr2i18n("This sets the rightmost wavelength of the spectrum.", nullptr));
#endif // QT_CONFIG(whatsthis)
        maximumValue->setSuffix(QString());
        groupBox->setTitle(tr2i18n("Spectrum Settings", nullptr));
        m_spectrumType->setItemText(0, tr2i18n("Emission spectrum", nullptr));
        m_spectrumType->setItemText(1, tr2i18n("Absorption spectrum", nullptr));

        label->setText(tr2i18n("Unit:", nullptr));
        label_2->setText(tr2i18n("Type:", nullptr));
        btn_resetZoom->setText(tr2i18n("Reset zoom", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SpectrumView: public Ui_SpectrumView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SPECTRUMVIEW_H

